# AzurLaneToolLib 
Tools lib for Azur Lane which game powered by ManJiu Shanghai.
## Copyright Information
### LICENSE 
> Copyright (C) 2021 - 2022 Matt Belfast Brown  
>   
> This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.  
>    
> This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.  
>   
> You should have received a copy of the GNU General Public License along with this program.  If not, see <https://www.gnu.org/licenses/> . 
### Author and Version  
#### Author Information  
> Author: ***Matt Belfast Brown*** or *Matt Brown* or *M.B.B.*（ **Name in English** ）  
>> Also be called ***The Day of The Doctor*** ( **Network Nickname** )  
>> ***鈴木夢美*** or ***伊藤京介*** ( **Name in Japanese** )  
>> ***沈永基***，***皓月***，***飞瀑山人***，***衍枫阁主人*** ( **Name in Chinese, Style Name, Pseudonym, Alias** )  
#### Contact Details 
> E-mail: ***thedayofthedo@gmail.com*** or ***thedayofthedoctor@foxmail.com***   
> TEL:\+86-15841486187 
>  
> Address: **Room 313, Apartment No. 14, South District, South Campus, Northwest A&F University, No. 22, Xinong Road, Litai Street, Yangling District, Shaanxi Province, China**  
> Address: ***中国陕西省杨凌区李台街道西农路22号西北农林科技大学南校区南区14号公寓313宿舍***  
## Version Information
### 0.5.1
+ Edit `mode_FCS_Cal.py` for complete the most basic functions.
+ function `fun_bsdg_fuca`, `fun_kstp_scco`, `fun_sfks_fuca` is available.
+ It can calculate the fuel consumption of surface kansens.
### 0.5.1a2
+ Add new mode from Azur Lane Fleet  (**author: x94fujo6rpg**). 
+ Rewrite file `setup.py`. 
+ Try adding a document.
## Update Log
| Release Version |    Status | Release Data | Update Info                 | 
|----------------:|----------:|:------------:|:----------------------------|
|           0.5.2 |   working |  2022-02-27  | Full mode for FCS_Cal.      |
|           0.5.1 | available |  2022-02-22  | New mode and new algorithm. |
|         0.5.1a2 | available |  2022-02-18  | Test for 0.5.1 and new md.  |
|          before | available |    before    | before                      |